@@ -58,7 +58,7 @@ class TestSKK(unittest.TestCase):
     def testinputmodechange(self):
         self.__skk.reset()
         self.assertEqual(self.__skk.conv_state, skk.CONV_STATE_NONE)
-        self.assertEqual(self.__skk.input_mode, skk.INPUT_MODE_NONE)
+        self.assertEqual(self.__skk.input_mode, skk.INPUT_MODE_DEFAULT)
         self.__skk.activate_input_mode(skk.INPUT_MODE_HIRAGANA)
         # catch ctrl-j in HIRAGANA
         handled, output = self.__skk.press_key(u'ctrl+j')
@@ -183,6 +183,16 @@ class TestSKK(unittest.TestCase):
         self.__skk.activate_input_mode(skk.INPUT_MODE_HIRAGANA)
         self.__skk.press_key(u'z')
         self.assertEqual(self.__skk.press_key(u'l'), (True, u'→'))
+        # cancel rom-kana conversion
+        self.__skk.reset()
+        self.__skk.activate_input_mode(skk.INPUT_MODE_HIRAGANA)
+        self.__skk.press_key(u'm')
+        self.__skk.press_key(u'y')
+        self.assertEqual(self.__skk.press_key(u'ctrl+g'), (True, u''))
+        self.__skk.press_key(u'm')
+        self.__skk.press_key(u'y')
+        self.__skk.press_key(u'a')
+        self.assertEqual(self.__skk.press_key(u'ctrl+g'), (False, u''))
 
     def testhiraganakatakana(self):
         self.__skk.reset()
@@ -226,6 +236,12 @@ class TestSKK(unittest.TestCase):
         handled, output = self.__skk.press_key(u'q')
         self.assertTrue(handled)
         self.assertEqual(output, u'ン')
+        # Wo -> ▽を (Issue#36)
+        self.__skk.reset()
+        self.__skk.activate_input_mode(skk.INPUT_MODE_HIRAGANA)
+        self.__skk.press_key(u'W')
+        self.__skk.press_key(u'o')
+        self.assertEqual(self.__skk.preedit, u'▽を')
 
     def testokurinasi(self):
         self.__skk.reset()
